@@ -59,7 +59,6 @@ int FillFptrTable() {
   FptrTableV1["burst_number"] = &LibV1::burst_number;
   FptrTableV1["AP_amplitude_diff"] = &LibV1::AP_amplitude_diff;
   FptrTableV1["AHP_depth_diff"] = &LibV1::AHP_depth_diff;
-  FptrTableV1["threshold_current"] = &LibV1::threshold_current;
 
   //****************** for FptrTableV1 *****************************
 
@@ -272,6 +271,20 @@ int FillFptrTable() {
   FptrTableV5["min_between_peaks_indices"] = &LibV5::min_between_peaks_indices;
   FptrTableV5["min_between_peaks_values"] = &LibV5::min_between_peaks_values;
   FptrTableV5["AP_width_between_threshold"] = &LibV5::AP_width_between_threshold;
+
+  FptrTableV5["burst_begin_indices"] = &LibV5::burst_begin_indices;
+  FptrTableV5["burst_end_indices"] = &LibV5::burst_end_indices;
+  FptrTableV5["strict_burst_mean_freq"] = &LibV5::strict_burst_mean_freq;
+  FptrTableV5["strict_burst_number"] = &LibV5::strict_burst_number;
+  FptrTableV5["strict_interburst_voltage"] = &LibV5::strict_interburst_voltage;
+
+  FptrTableV5["ADP_peak_indices"] = &LibV5::ADP_peak_indices;
+  FptrTableV5["ADP_peak_values"] = &LibV5::ADP_peak_values;
+  FptrTableV5["ADP_peak_amplitude"] = &LibV5::ADP_peak_amplitude;
+
+  FptrTableV5["interburst_min_indices"] = &LibV5::interburst_min_indices;
+  FptrTableV5["interburst_min_values"] = &LibV5::interburst_min_values;
+  FptrTableV5["time_to_interburst_min"] = &LibV5::time_to_interburst_min;
   
   //****************** end of FptrTableV5 *****************************
 
