@@ -181,7 +181,18 @@ int LibV1::ISI_values(mapStr2intVec& IntFeatureData,
     GErrorStr += "\n Three spikes required for calculation of ISI_values.\n";
     return -1;
   }
-  for (size_t i = 2; i < pvTime.size(); i++)
+
+  int IgnoreFirstISI;
+  vector<int> retIgnore;
+  retVal = getIntParam(IntFeatureData, "ignore_first_ISI", retIgnore);
+  if ((retVal == 1) && (retIgnore.size() > 0) && (retIgnore[0] == 0)) {
+    IgnoreFirstISI = 0;
+  }
+  else {
+    IgnoreFirstISI = 1;
+   }
+
+  for (size_t i = IgnoreFirstISI + 1; i < pvTime.size(); i++)
     VecISI.push_back(pvTime[i] - pvTime[i - 1]);
   setVec(DoubleFeatureData, StringData, "ISI_values", VecISI);
   return VecISI.size();
@@ -703,28 +714,33 @@ int LibV1::burst_ISI_indices(mapStr2intVec& IntFeatureData,
   return retVal;
 }
 
+// discrepancy betwen PVTime indices and BurstIndex indices because
+// first ISI value is ignored
 static int __burst_mean_freq(vector<double>& PVTime, vector<int>& BurstIndex,
+                             int IgnoreFirstISI,
                              vector<double>& BurstMeanFreq) {
-  vector<double> tmpVec;
-  BurstIndex.insert(BurstIndex.begin(), 0);
-  for (size_t i = 0; i < BurstIndex.size(); i++) tmpVec.push_back(0);
+  // if no burst detected, do not consider all peaks in a single burst
+  if (BurstIndex.size() == 0) return BurstMeanFreq.size();
   double span;
   size_t i;
+
+  // 1st burst
+  span = PVTime[BurstIndex[0] - 1 + IgnoreFirstISI] - PVTime[0];
+  BurstMeanFreq.push_back((BurstIndex[0] + IgnoreFirstISI) * 1000 / span);
+
   for (i = 0; i < BurstIndex.size() - 1; i++) {
-    if (BurstIndex[i + 1] - BurstIndex[i] == 1) {
-      tmpVec.push_back(0);
-    } else {
-      span = PVTime[BurstIndex[i + 1] - 1] - PVTime[BurstIndex[i]];
-      tmpVec.push_back((BurstIndex[i + 1] - BurstIndex[i] + 1) * 1000 / span);
+    if (BurstIndex[i + 1] - BurstIndex[i] > 1) {
+      span = PVTime[BurstIndex[i + 1] - 1 + IgnoreFirstISI] - PVTime[BurstIndex[i] + IgnoreFirstISI];
+      BurstMeanFreq.push_back((BurstIndex[i + 1] - BurstIndex[i]) * 1000 / span);
     }
   }
-  // NOW LAST BURST
-  span = PVTime[PVTime.size() - 1] - PVTime[BurstIndex[i]];
-  tmpVec.push_back((PVTime.size() - 1 - BurstIndex[i] + 1) * 1000 / span);
 
-  for (i = 0; i < tmpVec.size(); i++) {
-    if (tmpVec[i] != 0) BurstMeanFreq.push_back(tmpVec[i]);
-  }
+  // last burst
+  if (PVTime.size() - IgnoreFirstISI - BurstIndex[i] > 1) {
+      span = PVTime[PVTime.size() - 1] - PVTime[BurstIndex[i] + IgnoreFirstISI];
+      BurstMeanFreq.push_back((PVTime.size() - IgnoreFirstISI - BurstIndex[i]) * 1000 / span);
+    }
+
   return BurstMeanFreq.size();
 }
 
@@ -737,7 +753,8 @@ int LibV1::burst_mean_freq(mapStr2intVec& IntFeatureData,
   if (retVal)
     return nSize;
 
-  vector<int> BurstIndex;
+  int IgnoreFirstISI;
+  vector<int> BurstIndex, retIgnore;
   vector<double> BurstMeanFreq, PVTime;
   retVal = getVec(DoubleFeatureData, StringData, "peak_time", PVTime);
   if (retVal < 0) return -1;
@@ -745,7 +762,15 @@ int LibV1::burst_mean_freq(mapStr2intVec& IntFeatureData,
                      BurstIndex);
   if (retVal < 0) return -1;
 
-  retVal = __burst_mean_freq(PVTime, BurstIndex, BurstMeanFreq);
+  retVal = getIntParam(IntFeatureData, "ignore_first_ISI", retIgnore);
+  if ((retVal == 1) && (retIgnore.size() > 0) && (retIgnore[0] == 0)) {
+    IgnoreFirstISI = 0;
+  }
+  else {
+    IgnoreFirstISI = 1;
+   }
+
+  retVal = __burst_mean_freq(PVTime, BurstIndex, IgnoreFirstISI, BurstMeanFreq);
   if (retVal >= 0) {
     setVec(DoubleFeatureData, StringData, "burst_mean_freq",
                  BurstMeanFreq);
@@ -773,17 +798,19 @@ int LibV1::burst_number(mapStr2intVec& IntFeatureData,
   return (BurstNum.size());
 }
 
+// reminder: first ISI value is ignored in burst_ISI_indices if IgnoreFirstISI=1
 static int __interburst_voltage(vector<int>& BurstIndex, vector<int>& PeakIndex,
                                 vector<double>& T, vector<double>& V,
+                                int IgnoreFirstISI,
                                 vector<double>& IBV) {
-  if (BurstIndex.size() < 2) return 0;
+  if (BurstIndex.size() < 1) return 0;
   int j, pIndex, tsIndex, teIndex, cnt;
   double tStart, tEnd, vTotal = 0;
   for (size_t i = 0; i < BurstIndex.size(); i++) {
-    pIndex = BurstIndex[i] - 1;
+    pIndex = BurstIndex[i] + IgnoreFirstISI - 1;
     tsIndex = PeakIndex[pIndex];
     tStart = T[tsIndex] + 5;  // 5Millisecond after
-    pIndex = BurstIndex[i];
+    pIndex = BurstIndex[i] + IgnoreFirstISI;
     teIndex = PeakIndex[pIndex];
     tEnd = T[teIndex] - 5;  // 5Millisecond before
 
@@ -813,7 +840,8 @@ int LibV1::interburst_voltage(mapStr2intVec& IntFeatureData,
   if (retVal)
     return nSize;
 
-  vector<int> BurstIndex, PeakIndex;
+  int IgnoreFirstISI;
+  vector<int> BurstIndex, PeakIndex, retIgnore;
   vector<double> V, T, IBV;
   retVal = getVec(IntFeatureData, StringData, "peak_indices", PeakIndex);
   if (retVal < 0) return -1;
@@ -825,7 +853,15 @@ int LibV1::interburst_voltage(mapStr2intVec& IntFeatureData,
   retVal = getVec(DoubleFeatureData, StringData, "V", V);
   if (retVal < 0) return -1;
 
-  retVal = __interburst_voltage(BurstIndex, PeakIndex, T, V, IBV);
+  retVal = getIntParam(IntFeatureData, "ignore_first_ISI", retIgnore);
+  if ((retVal == 1) && (retIgnore.size() > 0) && (retIgnore[0] == 0)) {
+    IgnoreFirstISI = 0;
+  }
+  else {
+    IgnoreFirstISI = 1;
+   }
+
+  retVal = __interburst_voltage(BurstIndex, PeakIndex, T, V, IgnoreFirstISI, IBV);
   if (retVal >= 0) {
     setVec(DoubleFeatureData, StringData, "interburst_voltage", IBV);
   }
@@ -1354,8 +1390,8 @@ static int __time_constant(const vector<double>& v, const vector<double>& t,
   // golden section search algorithm
   const double PHI = 1.618033988;
   vector<double> x(3, .0);
-  // time_constant is searched in between 0 and 200 ms
-  x[2] = min_derivative * 200.;
+  // time_constant is searched in between 0 and 1000 ms
+  x[2] = min_derivative * 1000.;
   x[1] = (x[0] * PHI + x[2]) / (1. + PHI);
   // calculate residuals at x[1]
   for (size_t i = 0; i < log_v.size(); i++) {
@@ -1717,22 +1753,6 @@ int LibV1::single_burst_ratio(mapStr2intVec& IntFeatureData,
   return retval;
 }
 
-// *** threshold_current ***
-// just return the value for threshold_current which has been inserted
-int LibV1::threshold_current(mapStr2intVec& IntFeatureData,
-                             mapStr2doubleVec& DoubleFeatureData,
-                             mapStr2Str& StringData) {
-  int retval;
-  int nsize;
-  retval = CheckInMap(DoubleFeatureData, StringData,
-                            "threshold_current", nsize);
-  if (retval) {
-    return nsize;
-  }
-  return retval;
-}
-// end of threshold_current
-
 int LibV1::printVectorI(char* strName, vector<int> vec) {
   size_t nSize = 0;
   vector<int>::iterator pos1, pos2;
@@ -1776,9 +1796,10 @@ int LibV1::printVectorD(char* strName, vector<double> vec) {
 // unfortunately spike width means the width of the spike on onset not at half
 // maximum
 static int __AP_width(const vector<double>& t, const vector<double>& v,
-                      double stimstart, double threshold,
+                      double stimstart, double stimend, double threshold,
                       const vector<int>& peakindices,
                       const vector<int>& minahpindices,
+                      const bool strict_stiminterval,
                       vector<double>& apwidth) {
   //   printf("\n Inside AP_width...\n");
   //   printVectorD("t", t);
@@ -1786,12 +1807,27 @@ static int __AP_width(const vector<double>& t, const vector<double>& v,
   //   printVectorI("peakindices", peakindices);
   //   printVectorI("minahpindices", minahpindices);
   //   printf("\nStimStart = %f , thereshold = %f ", stimstart, threshold);
-  vector<int> indices(minahpindices.size() + 1);
-  int start_index = distance(
-      t.begin(),
-      find_if(t.begin(), t.end(), bind2nd(greater_equal<double>(), stimstart)));
-  indices[0] = start_index;
-  copy(minahpindices.begin(), minahpindices.end(), indices.begin() + 1);
+  vector<int> indices;
+  if (strict_stiminterval){
+    int start_index = distance(
+        t.begin(),
+        find_if(t.begin(), t.end(), bind2nd(greater_equal<double>(), stimstart)));
+    int end_index =
+        distance(t.begin(),
+                 find_if(t.begin(), t.end(),
+                         std::bind2nd(std::greater_equal<double>(), stimend)));
+    indices.push_back(start_index);
+    for (size_t i = 0; i < minahpindices.size(); i++) {
+      if (start_index < minahpindices[i] && minahpindices[i] < end_index) {
+        indices.push_back(minahpindices[i]);
+      }
+    }
+  } else {
+    indices.push_back(0);
+    for (size_t i = 0; i < minahpindices.size(); i++) {
+      indices.push_back(minahpindices[i]);
+    }
+  }
   for (size_t i = 0; i < indices.size() - 1; i++) {
     /*
     // FWHM (not used):
@@ -1840,6 +1876,9 @@ int LibV1::AP_width(mapStr2intVec& IntFeatureData,
   vector<double> stimstart;
   retval = getVec(DoubleFeatureData, StringData, "stim_start", stimstart);
   if (retval < 0) return -1;
+  vector<double> stimend;
+  retval = getVec(DoubleFeatureData, StringData, "stim_end", stimend);
+  if (retval < 0) return -1;
   vector<int> peakindices;
   retval = getVec(IntFeatureData, StringData, "peak_indices", peakindices);
   if (retval <= 0) {
@@ -1850,9 +1889,18 @@ int LibV1::AP_width(mapStr2intVec& IntFeatureData,
   vector<int> minahpindices;
   retval = getVec(IntFeatureData, StringData, "min_AHP_indices", minahpindices);
   if (retval < 0) return -1;
+  bool strict_stiminterval;
+  vector<int> strict_stiminterval_vec;
+  retval = getIntParam(IntFeatureData, "strict_stiminterval",
+                       strict_stiminterval_vec);
+  if (retval <= 0) {
+    strict_stiminterval = false;
+  } else {
+    strict_stiminterval = bool(strict_stiminterval_vec[0]);
+  }
   vector<double> apwidth;
-  retval = __AP_width(t, v, stimstart[0], threshold[0], peakindices,
-                      minahpindices, apwidth);
+  retval = __AP_width(t, v, stimstart[0], stimend[0], threshold[0], peakindices,
+                      minahpindices, strict_stiminterval, apwidth);
   if (retval >= 0) {
     setVec(DoubleFeatureData, StringData, "AP_width", apwidth);
   }
